function [deviceNumber, type, serialNumber] = crsLiveTrackGetHIDdeviceNumber
%CRSLIVETRACKGETHIDDEVICENUMBER   This function gets the HID device number
% of a Cambridge Research Sysmtems LiveTrack eye tracker
%
% Searches for a HID device with the product name 'LiveTrack'. Returns the
% one with the lowest device number if several is present as well as the
% pruduct name (e.g. LiveTrack-FM or LiveTrack-AV).
%
% Also returns the type name and serialnumber
%
% If more than one LiveTrack device is present a list of device numbers
% and serial numbers are returned

% History:
% 09/2016 JT Created


% Get a list of all HID devices
try
    deviceList =  PsychHID('Devices');
catch
    fprintf(['\nIf you get an error here about PsychHID.mexw32 try \n ',...
        'copy the file: \\Psychtoolbox\\PsychContributed\\libusb-1.0.dll \n ',...
        'onto the folder: \\WINDOWS\\system32\\\n']);
        PsychHID('Devices'); % just to produce the error in command window
end

% get cell array of product names for all HID devices
productNames = arrayfun(@(x)x.product, deviceList,'UniformOutput',0);

% find the one(s) with the name 'LiveTrack'
productName = strfind(productNames, 'LiveTrack'); 

% if none found try the name 'HID Interface'
if all(cellfun('isempty', productName)),
    productName = strfind(productNames, 'HID Interface');
end
    
% remove empty entries
deviceNumber = find(not(cellfun('isempty', productName)));

% get cell array of product names for all HID devices
serialNumbersTMP = arrayfun(@(x)x.serialNumber, deviceList,'UniformOutput',0);

if isempty(deviceNumber),
    disp('No device named LiveTrack found!');
    return
end

% try to find if type is 'FM' or 'AV'
for i=1:length(deviceNumber),
    type(i,:)=productNames{deviceNumber(i)};
    serialNumber{i}=serialNumbersTMP{deviceNumber(i)};
end