function crsLiveTrackSetUVCParameters(deviceNumber,parameter,value)
% implements the PT_SET_UVC_PARAMETER report
% 	u16_t packetType;
% 	u16_t param;                // Set to 
% 	s32_t value;				// Set true to track left eye

% History:
% 10/2016 JT Created

if nargin<3,
    error('The three input parameters must be set: deviceNumber, parameter and value');
end


packetType = typecast(uint16(303), 'uint8');

if strcmpi(parameter,'UVC_FOCUS'),
    param = typecast(uint16(0), 'uint8');
elseif strcmpi(parameter,'UVC_ZOOM'),
    param = typecast(uint16(1), 'uint8');
elseif strcmpi(parameter,'UVC_PANTILT'),
    param = typecast(uint16(2), 'uint8');
elseif strcmpi(parameter,'UVC_BACKLIGHT'),
    param = typecast(uint16(3), 'uint8');
elseif strcmpi(parameter,'UVC_BRIGHTNESS'),
    param = typecast(uint16(4), 'uint8');
elseif strcmpi(parameter,'UVC_CONTRAST'),
    param = typecast(uint16(5), 'uint8');
elseif strcmpi(parameter,'UVC_GAIN'),   
    param = typecast(uint16(6), 'uint8');
elseif strcmpi(parameter,'UVC_HUE'),   
    param = typecast(uint16(7), 'uint8');
else
    error('parameter must be either UVC_FOCUS, UVC_ZOOM, UVC_PANTILT, UVC_BACKLIGHT, UVC_BRIGHTNESS, UVC_CONTRAST, UVC_GAIN or UVC_HUE');
end

value2 = typecast(uint32(round(value)), 'uint8');

report(1:2) = packetType;
report(3:4) = param;
report(5:8) = value2;

% fill the rest with zeros
report(9:64) = uint8(0);


err = PsychHID('SetReport', deviceNumber, 2, 0, report);
if err.n
    fprintf('\nPsychHID: SetReport error 0x%s. %s: %s\n',hexstr(err.n),err.name,err.description);
else
    fprintf('\nLiveTrack: parameters set.\n');
end
